@@ -46,10 +46,15 @@ namespace PerCederberg.Grammatica.Parser {
      * don't match any of the token patterns, a parse exception is thrown. 
      *
      * @author   Per Cederberg, <per at percederberg dot net>
-     * @version  1.2
+     * @version  1.4
      */
     public class Tokenizer {
     
+        /**
+         * The token list feature flag.
+         */
+        private bool useTokenList = false;
+
         /**
          * The string token matcher. This token matcher is used for all
          * string token patterns. This matcher implements a DFA to 
@@ -99,6 +104,11 @@ namespace PerCederberg.Grammatica.Parser {
          */
         private bool endOfBuffer = false;
 
+        /**
+         * The previous token in the token list.
+         */
+        private Token previousToken = null; 
+
         /**
          * Creates a new tokenizer for the specified input stream.
          * 
@@ -107,7 +117,44 @@ namespace PerCederberg.Grammatica.Parser {
         public Tokenizer(TextReader input) {
             this.input = input;
         }
-    
+
+        /**
+         * Checks if the token list feature is used. The token list 
+         * feature makes all tokens (including ignored tokens) link to 
+         * each other in a linked list. By default the token list feature 
+         * is not used.
+         *
+         * @return true if the token list feature is used, or 
+         *         false otherwise
+         *
+         * @see #setUseTokenList
+         * @see Token#getPreviousToken
+         * @see Token#getNextToken
+         *
+         * @since 1.4
+         */
+        public bool GetUseTokenList() {
+            return useTokenList;
+        }
+
+        /**
+         * Sets the token list feature flag. The token list feature makes
+         * all tokens (including ignored tokens) link to each other in a 
+         * linked list when active. By default the token list feature is
+         * not used.
+         *
+         * @param useTokenList   the token list feature flag
+         *
+         * @see #getUseTokenList
+         * @see Token#getPreviousToken
+         * @see Token#getNextToken
+         *
+         * @since 1.4
+         */
+        public void SetUseTokenList(bool useTokenList) {
+            this.useTokenList = useTokenList;
+        }
+
         /**
          * Returns a description of the token pattern with the
          * specified id.
@@ -208,6 +255,10 @@ namespace PerCederberg.Grammatica.Parser {
             
             do {
                 token = NextToken();
+                if (useTokenList && token != null) {
+                    token.SetPreviousToken(previousToken);
+                    previousToken = token;
+                }
                 if (token == null) {
                     return null;
                 } else if (token.GetPattern().IsError()) {
