@@ -88,21 +88,6 @@ class FirstPassAnalyzer extends GrammarAnalyzer {
         this.grammar = grammar;
     }
 
-    /**
-     * Analyzes a grammar parse tree root node. This method will
-     * return a pruned parse tree, where all the completely analyzed
-     * parts will have been removed. 
-     * 
-     * @param root           the parse tree root node
-     * 
-     * @return the new parse tree root node
-     * 
-     * @throws ParseException if the analysis discovered errors
-     */
-    public Node analyze(Node root) throws ParseException {
-        return process(root);
-    }
-
     /**
      * Sets the node value to the ignore message. If no message is 
      * set, no node value will be added.
@@ -216,13 +201,17 @@ class FirstPassAnalyzer extends GrammarAnalyzer {
      * @param node           the production node
      * 
      * @return the new production node
+     * 
+     * @throws ParseException if the node analysis discovered errors
      */
-    protected Node exitHeaderDeclaration(Production node) {
+    protected Node exitHeaderDeclaration(Production node) 
+        throws ParseException {
+
         String  name;
         String  value;
         
-        name = (String) node.getChildAt(0).getValue(0);
-        value = (String) node.getChildAt(2).getValue(0);
+        name = getStringValue(getChildAt(node, 0), 0);
+        value = getStringValue(getChildAt(node, 2), 0);
         grammar.addDeclaration(name, value);
         return null;
     }
@@ -260,19 +249,19 @@ class FirstPassAnalyzer extends GrammarAnalyzer {
         Node          child;
 
         // Create token pattern
-        name = getIdentifier((Token) node.getChildAt(0));
-        child = node.getChildAt(2);
-        type = ((Integer) child.getValue(0)).intValue();
-        str = (String) child.getValue(1);
+        name = getIdentifier((Token) getChildAt(node, 0));
+        child = getChildAt(node, 2);
+        type = getIntValue(child, 0);
+        str = getStringValue(child, 1);
         pattern = new TokenPattern(nextTokenId++, name, type, str);
 
         // Process optional ignore or error
         if (node.getChildCount() == 4) {
-            child = node.getChildAt(3);
-            token = (Token) child.getValue(0);
+            child = getChildAt(node, 3);
+            token = (Token) getValue(child, 0);
             str = null;
             if (child.getValueCount() == 2) {
-                str = (String) child.getValue(1);
+                str = getStringValue(child, 1);
             }
             switch (token.getId()) {
             case GrammarConstants.IGNORE:
@@ -306,9 +295,11 @@ class FirstPassAnalyzer extends GrammarAnalyzer {
      * @param node           the production node
      * 
      * @return the new production node
+     * 
+     * @throws ParseException if the node analysis discovered errors
      */
-    protected Node exitTokenValue(Production node) {
-        switch (node.getChildAt(0).getId()) {
+    protected Node exitTokenValue(Production node) throws ParseException {
+        switch (getChildAt(node, 0).getId()) {
         case GrammarConstants.QUOTED_STRING:
             node.addValue(new Integer(TokenPattern.STRING_TYPE));
             break;
@@ -316,7 +307,7 @@ class FirstPassAnalyzer extends GrammarAnalyzer {
             node.addValue(new Integer(TokenPattern.REGEXP_TYPE));
             break;
         }
-        node.addValue(node.getChildAt(0).getValue(0));
+        node.addValue(getStringValue(getChildAt(node, 0), 0));
         return node;
     }
 
@@ -327,13 +318,17 @@ class FirstPassAnalyzer extends GrammarAnalyzer {
      * @param node           the production node
      * 
      * @return the new production node
+     * 
+     * @throws ParseException if the node analysis discovered errors
      */
-    protected Node exitTokenHandling(Production node) {
-        Node  child = node.getChildAt(0);
+    protected Node exitTokenHandling(Production node) 
+        throws ParseException {
+
+        Node  child = getChildAt(node, 0);
 
         node.addValue(child);
         if (child.getValueCount() > 0) {
-            node.addValue(child.getValue(0));
+            node.addValue(getValue(child, 0));
         }
         return node;
     }
@@ -355,7 +350,7 @@ class FirstPassAnalyzer extends GrammarAnalyzer {
         ProductionPattern  production;
         String             name;
 
-        name = getIdentifier((Token) node.getChildAt(0));
+        name = getIdentifier((Token) getChildAt(node, 0));
         production = new ProductionPattern(nextProductionId++, name);
         grammar.addProduction(production,
                               node.getStartLine(),
