@@ -80,21 +80,6 @@ class SecondPassAnalyzer extends GrammarAnalyzer {
         this.grammar = grammar;
     }
 
-    /**
-     * Analyzes a grammar parse tree root node. This method will
-     * return a pruned parse tree, where all the completely analyzed
-     * parts will have been removed. 
-     * 
-     * @param root           the parse tree root node
-     * 
-     * @return the new parse tree root node
-     * 
-     * @throws ParseException if the analysis discovered errors
-     */
-    public Node analyze(Node root) throws ParseException {
-        return process(root);
-    }
-
     /**
      * Sets the node value to the token or production pattern. If no
      * matching pattern was found, an exception is thrown.
@@ -107,8 +92,8 @@ class SecondPassAnalyzer extends GrammarAnalyzer {
      */
     protected Node exitIdentifier(Token node) throws ParseException {
         String             name = node.getImage();
-        TokenPattern       token = grammar.getTokenPattern(name);
-        ProductionPattern  prod = grammar.getProductionPattern(name);
+        TokenPattern       token = grammar.getTokenPatternByName(name);
+        ProductionPattern  prod = grammar.getProductionPatternByName(name);
 
         if (token != null) {
             node.addValue(token);
@@ -213,10 +198,10 @@ class SecondPassAnalyzer extends GrammarAnalyzer {
         ProductionPatternAlternative  alt;
         Node                          child;
 
-        pattern = (ProductionPattern) node.getChildAt(0).getValue(0);
-        child = node.getChildAt(2);
+        pattern = (ProductionPattern) getValue(getChildAt(node, 0), 0);
+        child = getChildAt(node, 2);
         for (int i = 0; i < child.getValueCount(); i++) {
-            alt = (ProductionPatternAlternative) child.getValue(i);
+            alt = (ProductionPatternAlternative) getValue(child, i);
             try {
                 pattern.addAlternative(alt);
             } catch (ParserCreationException e) {
@@ -236,8 +221,10 @@ class SecondPassAnalyzer extends GrammarAnalyzer {
      * @param node           the production node
      * 
      * @return the new production node
+     * 
+     * @throws ParseException if the node analysis discovered errors
      */
-    protected Node exitProduction(Production node) {
+    protected Node exitProduction(Production node) throws ParseException {
         ProductionPatternAlternative  alt;
         ProductionPatternElement      elem;
         Node                          child;
@@ -245,10 +232,10 @@ class SecondPassAnalyzer extends GrammarAnalyzer {
         alt = new ProductionPatternAlternative();
         node.addValue(alt);
         for (int i = 0; i < node.getChildCount(); i++) {
-            child = node.getChildAt(i);
+            child = getChildAt(node, i);
             if (child.getId() == GrammarConstants.PRODUCTION_ATOM) {
                 for (int j = 0; j < child.getValueCount(); j++) {
-                    elem = (ProductionPatternElement) child.getValue(j);
+                    elem = (ProductionPatternElement) getValue(child, j);
                     alt.addElement(elem);
                 }
             } else if (child.getId() == GrammarConstants.PRODUCTION) {
@@ -279,10 +266,10 @@ class SecondPassAnalyzer extends GrammarAnalyzer {
         Object   obj;
 
         // Handle the alternatives
-        child = node.getChildAt(0);
+        child = getChildAt(node, 0);
         switch (child.getId()) {
         case GrammarConstants.IDENTIFIER:
-            obj = child.getValue(0);
+            obj = getValue(child, 0);
             if (obj instanceof TokenPattern) {
                 token = true;
                 id = ((TokenPattern) obj).getId();
@@ -293,7 +280,7 @@ class SecondPassAnalyzer extends GrammarAnalyzer {
             break;
         case GrammarConstants.QUOTED_STRING:
             token = true;
-            id = ((TokenPattern) child.getValue(0)).getId();
+            id = ((TokenPattern) getValue(child, 0)).getId();
             break;
         case GrammarConstants.LEFT_PAREN:
         case GrammarConstants.LEFT_BRACE:
@@ -307,14 +294,14 @@ class SecondPassAnalyzer extends GrammarAnalyzer {
                 min = 0;
                 max = 1;
             }
-            elem = getProductionElement(node.getChildAt(1));
+            elem = getProductionElement(getChildAt(node, 1));
             token = elem.isToken();
             id = elem.getId(); 
             break;
         }
 
         // Handle optional '?', '*' or '+'
-        child = node.getChildAt(node.getChildCount() - 1);
+        child = getChildAt(node, node.getChildCount() - 1);
         if (child.getId() == GrammarConstants.QUESTION_MARK) {
             min = 0;
             max = 1;
@@ -352,16 +339,16 @@ class SecondPassAnalyzer extends GrammarAnalyzer {
         ProductionPatternAlternative  alt;
         String                        str;
 
-        alt = (ProductionPatternAlternative) node.getValue(0);
+        alt = (ProductionPatternAlternative) getValue(node, 0);
         if (node.getValueCount() == 1 && isSimple(alt)) {
             return alt.getElement(0);
         } else {
-            str = currentProduction.getName() + " (subproduction " +
+            str = currentProduction.getName() + "(" + 
                   (nextSynteticId - 3000) + ")";
             prod = new ProductionPattern(nextSynteticId, str);
             prod.setSyntetic(true);
             for (int i = 0; i < node.getValueCount(); i++) {
-                alt = (ProductionPatternAlternative) node.getValue(i);
+                alt = (ProductionPatternAlternative) getValue(node, i);
                 try {
                     prod.addAlternative(alt);
                 } catch (ParserCreationException e) {
