@@ -35,6 +35,7 @@ package net.percederberg.grammatica.parser;
 
 import java.io.PrintStream;
 import java.io.PrintWriter;
+import java.util.ArrayList;
 import java.util.Vector;
 
 /**
@@ -42,7 +43,7 @@ import java.util.Vector;
  * in the parse tree, i.e. by the token and production classes. 
  *
  * @author   Per Cederberg, <per at percederberg dot net>
- * @version  1.1
+ * @version  1.2
  */
 public abstract class Node {
 
@@ -54,7 +55,7 @@ public abstract class Node {
     /**
      * The computed node values. 
      */
-    private Vector values = null;
+    private ArrayList values = null;
 
     /**
      * Checks if this node is hidden, i.e. if it should not be visible
@@ -202,6 +203,22 @@ public abstract class Node {
         return null; 
     }
     
+    /**
+     * Returns the number of descendant nodes.
+     * 
+     * @return the number of descendant nodes
+     * 
+     * @since 1.2
+     */
+    public int getDescendantCount() {
+        int  count = 0;
+        
+        for (int i = 0; i < getChildCount(); i++) {
+            count += 1 + getChildAt(i).getDescendantCount();
+        }
+        return count;
+    }
+
     /**
      * Returns the number of computed values associated with this
      * node. Any number of values can be associated with a node
@@ -241,9 +258,11 @@ public abstract class Node {
      * values in this node (as it is the same object).
      *
      * @return a vector with all values, or
-     *         null if no values have been set 
+     *         null if no values have been set
+     * 
+     * @since 1.2
      */
-    public Vector getAllValues() {
+    public ArrayList getAllValues() {
         return values;
     }
 
@@ -257,7 +276,7 @@ public abstract class Node {
     public void addValue(Object value) {
         if (value != null) {
             if (this.values == null) {
-                this.values = new Vector();
+                this.values = new ArrayList();
             }
             values.add(value);
         }
@@ -266,11 +285,28 @@ public abstract class Node {
     /**
      * Adds a set of computed values to this node.
      *
-     * @param values         the vector with node values
+     * @param values         the list with node values
      */
     public void addValues(Vector values) {
-        for (int i = 0; i < values.size(); i++) {
-            addValue(values.get(i));
+        if (values != null) {
+            for (int i = 0; i < values.size(); i++) {
+                addValue(values.get(i));
+            }
+        }
+    }
+
+    /**
+     * Adds a set of computed values to this node.
+     *
+     * @param values         the list with node values
+     * 
+     * @since 1.2
+     */
+    public void addValues(ArrayList values) {
+        if (values != null) {
+            for (int i = 0; i < values.size(); i++) {
+                addValue(values.get(i));
+            }
         }
     }
 
