@@ -42,7 +42,7 @@ import java.util.HashMap;
  * interface, as well as token handling.
  *
  * @author   Per Cederberg, <per at percederberg dot net>
- * @version  1.1
+ * @version  1.4
  */
 public abstract class Parser {
 
@@ -101,7 +101,7 @@ public abstract class Parser {
      * @param tokenizer      the tokenizer to use
      */
     Parser(Tokenizer tokenizer) {
-        this(tokenizer, new Analyzer());
+        this(tokenizer, null);
     }
 
     /**
@@ -112,7 +112,33 @@ public abstract class Parser {
      */
     Parser(Tokenizer tokenizer, Analyzer analyzer) {
         this.tokenizer = tokenizer;
-        this.analyzer = analyzer;
+        if (analyzer == null) {
+            this.analyzer = new Analyzer();
+        } else {
+            this.analyzer = analyzer;
+        }
+    }
+
+    /**
+     * Returns the tokenizer in use by this parser.
+     * 
+     * @return the tokenizer in use by this parser
+     * 
+     * @since 1.4
+     */
+    public Tokenizer getTokenizer() {
+        return tokenizer;
+    }
+    
+    /**
+     * Returns the analyzer in use by this parser.
+     * 
+     * @return the analyzer in use by this parser
+     * 
+     * @since 1.4
+     */
+    public Analyzer getAnalyzer() {
+        return analyzer;
     }
 
     /**
