@@ -32,6 +32,8 @@
  */
 
 using System;
+using System.Text;
+
 using PerCederberg.Grammatica.Parser.RE;
 
 /**
@@ -397,12 +399,33 @@ public class TestRegExp {
         FailMatchRegExp("a{2,3}+a", "aaa");
     }
 
+    /**
+     * Tests the quantifier backtracking for stack overflows.
+     * (Bug #3632)
+     */
+    public void TestQuantifierStackOverflow() {
+        StringBuilder  buffer = new StringBuilder();
+        String         str;
+        
+        for (int i = 0; i < 4096; i++) {
+            buffer.Append("a");
+        }
+        str = buffer.ToString();
+        MatchRegExp("a*" + str, str);
+        FailMatchRegExp("a*a" + str, str);
+        MatchRegExp("a*?b", str + "b");
+        FailMatchRegExp("a*?b", str);
+        MatchRegExp("a*+", str);
+        FailMatchRegExp("a*+a", str);
+    }
+
     /**
      * Tests matching of various logical operators. 
      */
     public void TestLogicalOperators() {
-        MatchRegExp("a|b", "a");
-        MatchRegExp("a|b", "b");
+        MatchRegExp("a|ab|b", "a");
+        MatchRegExp("a|ab|b", "b");
+        MatchRegExp("a|ab|b", "ab");
         MatchRegExp("(ab)", "ab");
         MatchRegExp("(a)(b)", "ab");
     }
